unit RegExp_main;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, ComCtrls, ExtCtrls, StdCtrls;

type
  TfrmRegExp = class(TForm)
    PageControl1: TPageControl;
    Panel1: TPanel;
    TabSheet1: TTabSheet;
    TabSheet2: TTabSheet;
    mmSource: TMemo;
    mmResult: TMemo;
    rgAction: TRadioGroup;
    GroupBox1: TGroupBox;
    cbGlobal: TCheckBox;
    cbIgnoreCase: TCheckBox;
    cbMultiLine: TCheckBox;
    Label1: TLabel;
    cobPattern: TComboBox;
    btnExecute: TButton;
    lblReplace: TLabel;
    cobReplace: TComboBox;
    procedure FormCreate(Sender: TObject);
    procedure FormCloseQuery(Sender: TObject; var CanClose: Boolean);
    procedure FormResize(Sender: TObject);
    procedure rgActionClick(Sender: TObject);
    procedure btnExecuteClick(Sender: TObject);
    procedure cobPatternChange(Sender: TObject);
  private
    { Private 錾 }
    procedure RegexpText;
    procedure RegexpReplace;
    procedure RegexpExecute;
  public
    { Public 錾 }
  end;

var
  frmRegExp: TfrmRegExp;

implementation

{$R *.dfm}

uses
  IniFiles, VBScript_RegExp_55_TLB;

procedure TfrmRegExp.FormCreate(Sender: TObject);
var
  Ini: TIniFile;
  StrList: TStringList;
  i: integer;
begin
  Ini := TIniFile.Create(ChangeFileExt(ParamStr(0), '.ini'));
  try
    StrList := TStringList.Create;
    try
      Ini.ReadSection('Pattern', StrList);
      for i := 0 to StrList.Count - 1 do
        cobPattern.Items.Add(Ini.ReadString('Pattern', StrList[i], ''));
      Ini.ReadSection('Replace', StrList);
      for i := 0 to StrList.Count - 1 do
        cobReplace.Items.Add(Ini.ReadString('Replace', StrList[i], ''));
    finally
      StrList.Free;
    end;

    cbGlobal.Checked := Ini.ReadBool('Option', 'Global', cbGlobal.Checked);
    cbIgnoreCase.Checked := Ini.ReadBool('Option', 'IgnoreCase', cbIgnoreCase.Checked);
    cbMultiLine.Checked := Ini.ReadBool('Option', 'MultiLine', cbMultiLine.Checked);

    rgAction.ItemIndex := Ini.ReadInteger('Action', 'ItemIndex', rgAction.ItemIndex);


  finally
    Ini.Free;
  end;

  Constraints.MinWidth := Width;
  Constraints.MinHeight := Height;

end;


procedure TfrmRegExp.FormCloseQuery(Sender: TObject; var CanClose: Boolean);
var
  Ini: TIniFile;
  i: integer;
begin
  Ini := TIniFile.Create(ChangeFileExt(ParamStr(0), '.ini'));
  try
    Ini.EraseSection('Pattern');
    Ini.EraseSection('Replace');
    for i := 0 to cobPattern.Items.Count - 1 do
      Ini.WriteString('Pattern', Format('Item%.2d', [i]), cobPattern.Items[i]);
    for i := 0 to cobReplace.Items.Count - 1 do
      Ini.WriteString('Replace', Format('Item%.2d', [i]), cobReplace.Items[i]);

    Ini.WriteBool('Option', 'Global', cbGlobal.Checked);
    Ini.WriteBool('Option', 'IgnoreCase', cbIgnoreCase.Checked);
    Ini.WriteBool('Option', 'MultiLine', cbMultiLine.Checked);

    Ini.WriteInteger('Action', 'ItemIndex', rgAction.ItemIndex);

  finally
    Ini.Free;
  end;
end;


procedure TfrmRegExp.FormResize(Sender: TObject);
begin
  //
end;


procedure TfrmRegExp.rgActionClick(Sender: TObject);
begin
  lblReplace.Enabled := (rgAction.ItemIndex = 1);
  cobReplace.Enabled := lblReplace.Enabled;
end;


procedure TfrmRegExp.cobPatternChange(Sender: TObject);
begin
  btnExecute.Enabled := cobPattern.Text <> '';
end;


procedure TfrmRegExp.btnExecuteClick(Sender: TObject);
begin
  if cobPattern.Text = '' then
  begin
    ShowMessage('K\͂ĂB');
    cobPattern.SetFocus;
    exit;
  end;

  if (cobReplace.Text = '') and (rgAction.ItemIndex = 1) then
  begin
    ShowMessage('u͂ĂB');
    cobReplace.SetFocus;
    exit;
  end;

  if (cobPattern.Text <> '') and (cobPattern.Items.IndexOf(cobPattern.Text) = -1) then
    cobPattern.Items.Insert(0, cobPattern.Text);
  if (cobReplace.Text <> '') and (cobReplace.Items.IndexOf(cobReplace.Text) = -1) then
    cobReplace.Items.Insert(0, cobReplace.Text);

  mmResult.Lines.Clear;

  case rgAction.ItemIndex of
    0: RegexpText;
    1: RegexpReplace;
    2: RegexpExecute;
  end;
end;


procedure TfrmRegExp.RegexpText;
var
  Regexp: TRegExp;
  Rtn: boolean;
begin
  Regexp := TRegExp.Create(nil);
  try
    Regexp.Global := cbGlobal.Checked;
    Regexp.IgnoreCase := cbIgnoreCase.Checked;
    Regexp.MultiLine := cbMultiLine.Checked;
    Regexp.Pattern := cobPattern.Text;
    Rtn := Regexp.Test(mmSource.Text);
    if Rtn then
      ShowMessage('p^[Ɉv܂B')
    else
      ShowMessage('p^[ƕsvłB')
  finally
    Regexp.Free;
  end;
end;


procedure TfrmRegExp.RegexpReplace;
var
  Regexp: TRegExp;
  Rtn: string;
begin
  Regexp := TRegExp.Create(nil);
  try
    Regexp.Global := cbGlobal.Checked;
    Regexp.IgnoreCase := cbIgnoreCase.Checked;
    Regexp.MultiLine := cbMultiLine.Checked;
    Regexp.Pattern := cobPattern.Text;
    Rtn := Regexp.Replace(mmSource.Text, cobReplace.Text);
    if Rtn <> mmSource.Text then
    begin
      mmResult.Text := Rtn;
      PageControl1.ActivePageIndex := 1;
    end
    else
      ShowMessage('p^[ƕsvłB');
  finally
    Regexp.Free;
  end;
end;


procedure TfrmRegExp.RegexpExecute;
var
  Regexp: TRegExp;
  MatCol: MatchCollection;
  Mat: Match;
  SubMat: SubMatches;
  i, k: integer;
begin
  Regexp := TRegExp.Create(nil);
  try
    Regexp.Global := cbGlobal.Checked;
    Regexp.IgnoreCase := cbIgnoreCase.Checked;
    Regexp.MultiLine := cbMultiLine.Checked;
    Regexp.Pattern := cobPattern.Text;
    MatCol := Regexp.Execute(mmSource.Text) as MatchCollection;
    if MatCol.Count >= 1 then
    begin
      for i := 0 to MatCol.Count - 1 do
      begin
        Mat := MatCol.Item[i] as Match;
        SubMat := Mat.SubMatches as SubMatches;
        for k := 0 to SubMat.Count - 1 do
          mmResult.Lines.Add(SubMat.Item[k]);
      end;
      PageControl1.ActivePageIndex := 1;
    end
    else
      ShowMessage('p^[ƕsvłB');
  finally
    Regexp.Free;
  end;
end;




end.
